/**
 * JASMINe
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMSTextMessageToJasmineEvent.java 5382 2009-09-21 16:46:05Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.transformers;

import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.jms.TextMessage;

import org.mule.transformers.AbstractTransformer;
import org.mule.umo.transformer.TransformerException;
import org.ow2.jasmine.event.beans.JasmineEventEB;

/**
 * Class implementing a Mule transformer to format JasmineEvent and
 * JasmineEventEB to CSV.
 */
public class JMSTextMessageToJasmineEvent extends AbstractTransformer {

    /**
     * Logger.
     */
    private final Logger logger = Logger.getLogger(this.getClass().getName());

    /**
     * Domain name.
     */
    private String domainName = null;

    /**
     * Server name.
     */
    private String serverName = null;

    /**
     * Source name.
     */
    private String sourceName = null;

    /**
     * The {@link JasmineEvent#getSname()} attribute.
     */
    private String sname = null;

    /**
     * @return Domain name.
     */
    public String getDomainName() {
        return this.domainName;
    }

    /**
     * @param domainName Domain name.
     */
    public void setDomainName(final String domainName) {
        this.domainName = domainName;
    }

    /**
     * @return Server name.
     */
    public String getServerName() {
        return this.serverName;
    }

    /**
     * @param serverName Server name.
     */
    public void setServerName(final String serverName) {
        this.serverName = serverName;
    }

    /**
     * @return Source name.
     */
    public String getSourceName() {
        return this.sourceName;
    }

    /**
     * @param sourceName Source name
     */
    public void setSourceName(final String sourceName) {
        this.sourceName = sourceName;
    }

    /**
     * @return The {@link JasmineEvent#getSname()} attribute.
     */
    public String getSname() {
        return this.sname;
    }

    /**
     * @param sname The {@link JasmineEvent#getSname()} attribute.
     */
    public void setSname(final String sname) {
        this.sname = sname;
    }

    /**
     * Registers the transformer on Mule.
     *
     * @see org.mule.transformers.AbstractTransformer
     */
    public JMSTextMessageToJasmineEvent() {
        super();
        this.registerSourceType(TextMessage.class);
        this.setReturnClass(JasmineEventEB.class);
    }

    @Override
    protected Object doTransform(final Object src, final String encoding) throws TransformerException {
        JasmineEventEB event = null;
        try {
            TextMessage textMessage = (TextMessage) src;
            String text = textMessage.getText();
            Date timestamp = new Date(textMessage.getJMSTimestamp());

            event = new JasmineEventEB(domainName, serverName, "JMS", sourceName, text, timestamp, sname);

            logger.finest("Sending event " + event);
        } catch (Exception e) {
            logger.log(Level.SEVERE, "Transformer exception", e);
            throw new TransformerException(this,e);
        }

        return event;
    }
}
